# Topology-related classes and utility functions

```eval_rst
.. currentmodule:: baggianalysis.core

.. autosummary::
    :nosignatures:

    Topology
    TopologyBond
    TopologyAngle
    TopologyDihedral
    parse_microgel_bondfile
    parse_polymer_bondfile
    parse_LAMMPS_topology
    topology_from_LAMMPS_data_file
    
.. autoclass:: Topology

.. autoclass:: TopologyBond

.. autoclass:: TopologyAngle

.. autoclass:: TopologyDihedral
    
.. autofunction:: parse_microgel_bondfile
.. autofunction:: parse_polymer_bondfile
.. autofunction:: parse_LAMMPS_topology
.. autofunction:: topology_from_LAMMPS_data_file
```
